pub struct PoWSolution {
pub nonce: [u8; 32],
pub solution: u64,
}Expand description
Proof-of-Work Solution
Fields
nonce: [u8; 32]solution: u64Trait Implementations
Sourceimpl BorshDeserialize for PoWSolution
impl BorshDeserialize for PoWSolution
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for PoWSolution
impl BorshSerialize for PoWSolution
Sourceimpl Clone for PoWSolution
impl Clone for PoWSolution
Sourcefn clone(&self) -> PoWSolution
fn clone(&self) -> PoWSolution
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PoWSolution
impl Debug for PoWSolution
Sourceimpl<'de> Deserialize<'de> for PoWSolution
impl<'de> Deserialize<'de> for PoWSolution
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more