pub enum FramingError {
FrameTooLarge {
len: usize,
capacity: usize,
},
}Available on crate feature
embedded only.Expand description
Errors from length-prefix framing.
Variants
FrameTooLarge
A frame length — declared on the wire, or requested for send — exceeds the fixed buffer capacity it has to fit in.