Module multiplexer

Module multiplexer 

Stream Demultiplexer

Routes incoming packets to their target streams based on stream_id extracted from PhantomPacket headers. Replaces the old smoltcp-based multiplexer with a lightweight, zero-copy routing table.

Structs

StreamDemultiplexer
A lightweight stream demultiplexer that routes packets to registered streams.
StreamHandle
Handle returned when a stream is registered with the demultiplexer.

Enums

StreamMessage
Messages routed to a stream by the demultiplexer.