pub struct ParsedPathValidation {
pub path_id: u8,
pub payload: [u8; 32],
}Expand description
A parsed incoming PATH_VALIDATION frame, with all fields the receiver needs to feed into the state machine.
Fields
path_id: u8payload: [u8; 32]Trait Implementations
Sourceimpl Clone for ParsedPathValidation
impl Clone for ParsedPathValidation
Sourcefn clone(&self) -> ParsedPathValidation
fn clone(&self) -> ParsedPathValidation
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ParsedPathValidation
impl Debug for ParsedPathValidation
impl Eq for ParsedPathValidation
Sourceimpl PartialEq for ParsedPathValidation
impl PartialEq for ParsedPathValidation
Sourcefn eq(&self, other: &ParsedPathValidation) -> bool
fn eq(&self, other: &ParsedPathValidation) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ParsedPathValidation