pub struct CryptoFrame {
pub session_id: [u8; 16],
pub packet_id: u32,
pub chunk_index: u16,
pub total_chunks: u16,
pub payload: Vec<u8>,
}Expand description
Represents a single chunk of a fragmented logical packet
Fields
session_id: [u8; 16]packet_id: u32chunk_index: u16total_chunks: u16payload: Vec<u8>Trait Implementations
Sourceimpl BorshDeserialize for CryptoFrame
impl BorshDeserialize for CryptoFrame
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for CryptoFrame
impl BorshSerialize for CryptoFrame
Sourceimpl Clone for CryptoFrame
impl Clone for CryptoFrame
Sourcefn clone(&self) -> CryptoFrame
fn clone(&self) -> CryptoFrame
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for CryptoFrame
impl RefUnwindSafe for CryptoFrame
impl Send for CryptoFrame
impl Sync for CryptoFrame
impl Unpin for CryptoFrame
impl UnsafeUnpin for CryptoFrame
impl UnwindSafe for CryptoFrame